==> gitlab-foss-v18.7.0.tar.bz2: gitlab-foss-v18.7.0/spec/views/help/instance_configuration.html.haml_spec.rb <==
# frozen_string_literal: true

require 'spec_helper'

RSpec.describe 'help/instance_configuration', feature_category: :configuration do
  describe 'General Sections:' do
    let(:instance_configuration) { build(:instance_configuration) }
    let(:settings) { instance_configuration.settings }
    let(:ssh_settings) { settings[:ssh_algorithms_hashes] }

    before do
      create(:plan, name: 'premium')
      assign(:instance_configuration, instance_configuration)
    end

    it 'has links to several sections' do
      render

      expect(rendered).to have_link(nil, href: '#ssh-host-keys-fingerprints') if ssh_settings.any?
      expect(rendered).to have_link(nil, href: '#gitlab-pages')
      expect(rendered).to have_link(nil, href: '#size-limits')
      expect(rendered).to have_link(nil, href: '#package-registry')
      expect(rendered).to have_link(nil, href: '#rate-limits')
      expect(rendered).to have_link(nil, href: '#users-api-rate-limits')
      expect(rendered).to have_link(nil, href: '#ci-cd-limits')
    end

    it 'has several sections' do
      render

      expect(rendered).to have_css('h2#ssh-host-keys-fingerprints') if ssh_settings.any?
      expect(rendered).to have_css('h2#gitlab-pages')
      expect(rendered).to have_css('h2#size-limits')
      expect(rendered).to have_css('h2#package-registry')
      expect(rendered).to have_css('h2#rate-limits')
      expect(rendered).to have_css('h2#users-api-rate-limits')
      expect(rendered).to have_css('h2#ci-cd-limits')
    end
  end
end

==> gitlab-foss-v18.8.2.tar.bz2: gitlab-foss-v18.8.2/spec/views/help/instance_configuration.html.haml_spec.rb <==
# frozen_string_literal: true

require 'spec_helper'

RSpec.describe 'help/instance_configuration', feature_category: :configuration do
  describe 'General Sections:' do
    let(:instance_configuration) { build(:instance_configuration) }
    let(:settings) { instance_configuration.settings }
    let(:ssh_settings) { settings[:ssh_algorithms_hashes] }

    before do
      create(:plan, name: 'premium')
      assign(:instance_configuration, instance_configuration)
    end

    it 'has links to several sections' do
      render

      expect(rendered).to have_link(nil, href: '#ssh-host-keys-fingerprints') if ssh_settings.any?
      expect(rendered).to have_link(nil, href: '#gitlab-pages')
      expect(rendered).to have_link(nil, href: '#size-limits')
      expect(rendered).to have_link(nil, href: '#package-registry')
      expect(rendered).to have_link(nil, href: '#rate-limits')
      expect(rendered).to have_link(nil, href: '#users-api-rate-limits')
      expect(rendered).to have_link(nil, href: '#groups-api-rate-limits')
      expect(rendered).to have_link(nil, href: '#projects-api-rate-limits')
      expect(rendered).to have_link(nil, href: '#ci-cd-limits')
    end

    it 'has several sections' do
      render

      expect(rendered).to have_css('h2#ssh-host-keys-fingerprints') if ssh_settings.any?
      expect(rendered).to have_css('h2#gitlab-pages')
      expect(rendered).to have_css('h2#size-limits')
      expect(rendered).to have_css('h2#package-registry')
      expect(rendered).to have_css('h2#rate-limits')
      expect(rendered).to have_css('h2#users-api-rate-limits')
      expect(rendered).to have_css('h2#groups-api-rate-limits')
      expect(rendered).to have_css('h2#projects-api-rate-limits')
      expect(rendered).to have_css('h2#ci-cd-limits')
    end
  end
end
